# SimpleComments 1.32 (with MT 3.2+ SpamLookup patch applied)
# $Id$
#
# Copyright 2003-2004 Kalsey Consulting Group & Adam Kalsey
# http://kalsey.com/
#
# Code to allow use outside an entry context
# Copyright 2003 Mark Paschal <markpasc@markpasc.org> 18 February 2003
#
# Port to MT/PHP
# Copyright 2004 Brad Choate <brad@bradchoate.com> 20 October 2004
#
# MT 3.2+ SpamLookup Patch by
#   Cameron Bulock <www.cbulock.com> 8 September 2005
#   Joe D'Andrea <www.joesapt.net> 9 September 2005

package MTPlugins::simplecomments;

use strict;
use MT;
use MT::Template::Context;
use MT::Plugin;
use SelfLoader;

use vars qw($VERSION);
$VERSION = 1.32;

my $plugin = new MT::Plugin();
$plugin->name("SimpleComments $VERSION");
$plugin->description('Merges Trackbacks and Comments into a single list.');
MT->add_plugin($plugin);

#MT::Template::Context->add_container_tag(SimpleComments => sub { require MTPlugins::simplecomments; &MTPlugins::simplecomments::SimpleComments; });
#MT::Template::Context->add_tag(SimpleCommentCount => sub { require MTPlugins::simplecomments; &MTPlugins::simplecomments::SimpleCommentCount; });
#MT::Template::Context->add_tag(SimpleCommentNumber => sub { require MTPlugins::simplecomments; &MTPlugins::simplecomments::SimpleCommentOrder; });
#MT::Template::Context->add_tag(SimpleCommentOdd => sub { require MTPlugins::simplecomments; &MTPlugins::simplecomments::SimpleCommentOdd; });
#MT::Template::Context->add_container_tag(SimpleCommentIfTrackback => sub { require MTPlugins::simplecomments; &MTPlugins::simplecomments::SimpleCommentIfTrackback; });
#MT::Template::Context->add_container_tag(SimpleCommentIfComment => sub { require MTPlugins::simplecomments; &MTPlugins::simplecomments::SimpleCommentIfComment; });
#MT::Template::Context->add_container_tag(SimpleCommentEntry => sub { require MTPlugins::simplecomments; &MTPlugins::simplecomments::SimpleCommentEntry; });

MT::Template::Context->add_container_tag(SimpleComments => \&SimpleComments);
MT::Template::Context->add_tag(SimpleCommentCount => \&SimpleCommentCount);
MT::Template::Context->add_tag(SimpleCommentNumber => \&SimpleCommentOrder);
MT::Template::Context->add_tag(SimpleCommentOdd => \&SimpleCommentOdd);
MT::Template::Context->add_container_tag(SimpleCommentIfTrackback => \&SimpleCommentIfTrackback);
MT::Template::Context->add_container_tag(SimpleCommentIfComment => \&SimpleCommentIfComment);
MT::Template::Context->add_container_tag(SimpleCommentEntry => \&SimpleCommentEntry);

1;

__DATA__

sub SimpleComments {
    my($ctx, $args) = @_;
    my $e = $ctx->stash('entry');
    my $blog_id = $ctx->stash('blog_id');
    my($tb, $cat);
    my $so = $args->{sort_order} || $ctx->stash('blog')->sort_order_comments;
    my $limit = $args->{lastn} ? $args->{lastn} : '';
    my $moderate = defined($args->{moderate}) ? $args->{moderate} : 1;

    my %args = ('sort' => 'created_on', 'direction' => $so);
    if($limit) {
        $args{direction} = 'descend';
        $args{limit} = $limit;
    };

    my (@comments, @pings);
    require MT::Trackback;
    require MT::TBPing;
	require MT;
    if($e) {
        @comments = @{$e->comments};
		@comments = grep { $_->visible() } @comments
			if MT->version_number >= 3 && $moderate;
        $tb = MT::Trackback->load({ entry_id => $e->id });  # MT::Trackback is how you convert entry IDs to TB IDs.
        if ($tb) {
            my %terms;
            $terms{tb_id} = $tb->id if $tb;
            $terms{blog_id} = $blog_id;
		$terms{visible} = 1
			if MT->version_number >= 3.2 && $moderate;
            @pings = MT::TBPing->load(\%terms, \%args);
        };
    } else {
        my %terms;
        $terms{blog_id} = $blog_id;
		$terms{visible} = 1
			if MT->version_number >= 3.2 && $moderate;
        @pings = MT::TBPing->load(\%terms, \%args);
		$terms{visible} = 1
			if MT->version_number >= 3 && $moderate;
        @comments = MT::Comment->load(\%terms, \%args);
    };

    my @allComments = (@comments, @pings);
    return '' unless scalar(@allComments);
    @allComments = $so eq 'ascend' ?
        sort { $a->created_on <=> $b->created_on } @allComments :
        sort { $b->created_on <=> $a->created_on } @allComments;
    if ($limit) {
        my $max = $args->{lastn} > scalar(@allComments) ? scalar(@allComments)-1 : $args->{lastn}-1;
        @allComments = $so eq 'ascend' ? @allComments[-$max-1..-1] : @allComments[0..$max];
    }
    my $builder = $ctx->stash('builder');
    my $tokens = $ctx->stash('tokens');
    my $res = '';
    my $ordernumber = 1;
    for my $c (@allComments) {
        $ctx->stash('_simplecomment_order' => $ordernumber++);
        $ctx->stash('comment' => $c);
        $ctx->stash('ping' => $c);
        local $ctx->{current_timestamp} = $c->created_on;
        my $out = $builder->build($ctx, $tokens);
        return $ctx->error( $builder->errstr ) unless defined $out;
        $res .= $out;
    }
    $res;
}

sub SimpleCommentCount {
    my $e = $_[0]->stash('entry')
        or return $_[0]->error('Perhaps you used MTSimpleCommentCount outside an entry?');
    $e->ping_count + $e->comment_count;
}

sub SimpleCommentOrder {
    my $ctx = shift;
    $ctx->stash('_simplecomment_order');
}

sub SimpleCommentOdd {
    my $ctx = shift;
    return ($ctx->stash('_simplecomment_order') % 2 == 1) ? '1' : '0';
}

sub SimpleCommentIfComment {
    my $ctx = shift;
    my $comment = $ctx->stash('comment')
        or return $ctx->error('MTSimpleCommentIfComment must be used inside a SimpleComments container');
    return '' if (!defined($comment->text) || length($comment->text)==0);
    my $builder = $ctx->stash('builder');
    my $tokens = $ctx->stash('tokens');
    defined(my $out = $builder->build($ctx,$tokens))
        or return '';
    return $out;
}

sub SimpleCommentIfTrackback {
    my $ctx = shift;
    my $comment = $ctx->stash('comment')
        or return $ctx->error('MTSimpleCommentIfTrackback must be used inside a SimpleComments container');
    return '' if (!defined($comment->source_url) && !defined($comment->title));
    my $builder = $ctx->stash('builder');
    my $tokens = $ctx->stash('tokens');
    defined(my $out = $builder->build($ctx,$tokens))
        or return '';
    return $out;
}

sub SimpleCommentEntry {
    my $ctx = shift;
    my $comment = $ctx->stash('comment')
        or return $ctx->error('MTSimpleCommentEntry must be used inside a SimpleComments container');
    my $entry_id = $comment->entry_id 
        || MT::Trackback->load($comment->tb_id)->entry_id;
    my $entry = MT::Entry->load($entry_id)
        or return '';
    local $ctx->{__stash}{entry} = $entry;
    local $ctx->{current_timestamp} = $entry->created_on;
    $ctx->stash('builder')->build($ctx, $ctx->stash('tokens'));
}

__END__
